<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0"
		        xmlns="http://www.w3.org/1999/xhtml"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:msa="http://www.publictalksoftware.co.uk/msa">
	<!-- Output specification -->
	<xsl:output method="html" indent="yes" version="4.01"
	  doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"
	  doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"/>

	<!-- Parameters -->
	<xsl:param name="CSSFile1"></xsl:param>

	<xsl:template match="/">
		<html xmlns="http://www.w3.org/1999/xhtml">
			<head>
				<title>Publishers Report</title>
				<xsl:choose>
					<xsl:when test="$CSSFile1 !=''">
						<style type="text/css">
							<xsl:value-of select="$CSSFile1"/>
						</style>
					</xsl:when>
					<xsl:otherwise>
						<link rel="stylesheet" type="text/css" href="Custom--S-140--Student Report.css"/>
					</xsl:otherwise>
				</xsl:choose>
			</head>
			<body>
				<xsl:variable name="PubDB" select="document('MSA_PublisherDatabase.XML')"/>
				<xsl:variable name="Labels" select="document('LabelsInfo.XML')"/>
				<table>
					<thead>
						<tr>
							<th class="cellSortHeading" id="column-1">Student</th>
							<th class="cellSortHeading" id="column-2">Last As Student</th>
							<th class="cellSortHeading" id="column-3">Last Bible Reading</th>
							<th class="cellSortHeading" id="column-4">Last Discussion</th>
							<th class="cellSortHeading" id="column-5">Last Talk</th>
							<th class="cellSortHeading" id="column-6">Last Assistant</th>
						</tr>
					</thead>
					<tbody>
						<xsl:apply-templates select="$PubDB/msa:PublisherDatabase/msa:Publishers/msa:Publisher[
											 msa:Assignments/@StudentBibleReading='true' or
											 msa:Assignments/@StudentDiscussion='true' or
											 msa:Assignments/@StudentTalk='true' or
											 msa:Assignments/@Assistant='true']">
							<xsl:sort select="msa:Name" data-type="text" order="ascending"/>
							<xsl:with-param name="strAssistant" select="$Labels/Labels/Assistant"/>
							<xsl:with-param name="strBibleReading" select="$Labels/Labels/BibleReading"/>
							<xsl:with-param name="strTalk" select="$Labels/Labels/Talk"/>
							<xsl:with-param name="NowDay" select="/MeetingWorkBook/Settings/Now/@Day"/>
							<xsl:with-param name="NowMonth" select="/MeetingWorkBook/Settings/Now/@Month"/>
							<xsl:with-param name="NowYear" select="/MeetingWorkBook/Settings/Now/@Year"/>
						</xsl:apply-templates>
					</tbody>
				</table>
			</body>
		</html>
	</xsl:template>

	<xsl:template match="msa:Publisher">
		<xsl:param name="strAssistant"/>
		<xsl:param name="strBibleReading"/>
		<xsl:param name="strTalk"/>
		<xsl:param name="NowDay"/>
		<xsl:param name="NowMonth"/>
		<xsl:param name="NowYear"/>
		<xsl:variable name="HistoryDB" select="document('AssignHistory.XML')"/>
		<xsl:variable name ="SearchName" select="msa:Name"/>
		<tr>
			<!--The first cell is the name-->
			<td>
				<xsl:value-of select="msa:Name"/>
			</td>

			<!--The next cell is the most recent Student date-->
			<!--We sort the entries in date descending order so that the first entry is the most recent-->
			<td class="cellDate">
				<xsl:choose>
					<xsl:when test="$HistoryDB/AssignmentHistory/*/StudentItems/Item[Type != $strAssistant and Name = $SearchName]">
						<xsl:for-each select="$HistoryDB/AssignmentHistory/*/StudentItems/Item[Type != $strAssistant and Name = $SearchName]">
							<xsl:sort select="name(../..)" order="descending" data-type="text"/>
							<!--We only want the first entry-->
							<xsl:if test="position()=1">
								<xsl:call-template name="DisplayItemDate">
									<xsl:with-param name="ItemDate" select="name(../..)"/>
									<xsl:with-param name="NowDay" select="$NowDay"/>
									<xsl:with-param name="NowMonth" select="$NowMonth"/>
									<xsl:with-param name="NowYear" select="$NowYear"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:for-each>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>&#160;</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</td>

			<!--The next cell is the most recent Bible Reading date-->
			<!--We sort the entries in date descending order so that the first entry is the most recent-->
			<td class="cellDate">
				<xsl:choose>
					<xsl:when test="$HistoryDB/AssignmentHistory/*/StudentItems/Item[Description = $strBibleReading and Name = $SearchName]">
						<xsl:for-each select="$HistoryDB/AssignmentHistory/*/StudentItems/Item[Description = $strBibleReading and Name = $SearchName]">
							<xsl:sort select="name(../..)" order="descending" data-type="text"/>
							<!--We only want the first entry-->
							<xsl:if test="position()=1">
								<xsl:call-template name="DisplayItemDate">
									<xsl:with-param name="ItemDate" select="name(../..)"/>
									<xsl:with-param name="NowDay" select="$NowDay"/>
									<xsl:with-param name="NowMonth" select="$NowMonth"/>
									<xsl:with-param name="NowYear" select="$NowYear"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:for-each>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>&#160;</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</td>

			<!--The next cell is the most recent Publisher date-->
			<!--We sort the entries in date descending order so that the first entry is the most recent-->
			<td class="cellDate">
				<xsl:choose>
					<xsl:when test="$HistoryDB/AssignmentHistory/*/StudentItems/Item[Description != $strTalk and Description != $strBibleReading and Type != $strAssistant and Name = $SearchName]">
						<xsl:for-each select="$HistoryDB/AssignmentHistory/*/StudentItems/Item[Description != $strTalk and Description != $strBibleReading and Type != $strAssistant and Name = $SearchName]">
							<xsl:sort select="name(../..)" order="descending" data-type="text"/>
							<!--We only want the first entry-->
							<xsl:if test="position()=1">
								<xsl:call-template name="DisplayItemDate">
									<xsl:with-param name="ItemDate" select="name(../..)"/>
									<xsl:with-param name="NowDay" select="$NowDay"/>
									<xsl:with-param name="NowMonth" select="$NowMonth"/>
									<xsl:with-param name="NowYear" select="$NowYear"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:for-each>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>&#160;</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</td>

			<!--The next cell is the most recent Talk date-->
			<!--We sort the entries in date descending order so that the first entry is the most recent-->
			<td class="cellDate">
				<xsl:choose>
					<xsl:when test="$HistoryDB/AssignmentHistory/*/StudentItems/Item[(Description = $strTalk or Description = 'Explaining Your Beliefs (Talk)') and Name = $SearchName]">
						<xsl:for-each select="$HistoryDB/AssignmentHistory/*/StudentItems/Item[(Description = $strTalk or Description = 'Explaining Your Beliefs (Talk)') and Name = $SearchName]">
							<xsl:sort select="name(../..)" order="descending" data-type="text"/>
							<!--We only want the first entry-->
							<xsl:if test="position()=1">
								<xsl:call-template name="DisplayItemDate">
									<xsl:with-param name="ItemDate" select="name(../..)"/>
									<xsl:with-param name="NowDay" select="$NowDay"/>
									<xsl:with-param name="NowMonth" select="$NowMonth"/>
									<xsl:with-param name="NowYear" select="$NowYear"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:for-each>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>&#160;</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</td>

			<!--The last cell is the most recent Assistant date-->
			<!--We sort the entries in date descending order so that the first entry is the most recent-->
			<td class="cellDate">
				<xsl:choose>
					<!-- Check if there are any matching Item nodes -->
					<xsl:when test="$HistoryDB/AssignmentHistory/*/StudentItems/Item[Type = $strAssistant and Name = $SearchName]">
						<xsl:for-each select="$HistoryDB/AssignmentHistory/*/StudentItems/Item[Type = $strAssistant and Name = $SearchName]">
							<xsl:sort select="name(../..)" order="descending" data-type="text"/>
							<!-- We only want the first entry -->
							<xsl:if test="position()=1">
								<xsl:call-template name="DisplayItemDate">
									<xsl:with-param name="ItemDate" select="name(../..)"/>
									<xsl:with-param name="NowDay" select="$NowDay"/>
									<xsl:with-param name="NowMonth" select="$NowMonth"/>
									<xsl:with-param name="NowYear" select="$NowYear"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:for-each>
					</xsl:when>
					<!-- If no matching nodes were found -->
					<xsl:otherwise>
						<xsl:text>&#160;</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</td>
		</tr>
	</xsl:template>

	<xsl:template name="DisplayItemDate">
		<xsl:param name="ItemDate"/>
		<xsl:param name="NowDay" select="//MeetingWorkBook/Settings/Now/@Day"/>
		<xsl:param name="NowMonth" select="//MeetingWorkBook/Settings/Now/@Month"/>
		<xsl:param name="NowYear" select="//MeetingWorkBook/Settings/Now/@Year"/>

		<xsl:variable name="Day" select="substring($ItemDate, 8, 2)"/>
		<xsl:variable name="Month" select="substring($ItemDate, 6, 2)"/>
		<xsl:variable name="Year" select="substring($ItemDate, 2, 4)"/>

		<span>
			<xsl:if test="($Day &gt; $NowDay and $Month &gt;= $NowMonth and $Year &gt;= $NowYear) or ($Month &gt; $NowMonth and $Year &gt;= $NowYear) or ($Year &gt; $NowYear)">
				<xsl:attribute name="class">FutureDate</xsl:attribute>
			</xsl:if>
			<xsl:value-of select="$Day"/>
			<xsl:text>/</xsl:text>
			<xsl:value-of select="$Month"/>
			<xsl:text>/</xsl:text>
			<xsl:value-of select="$Year"/>
		</span>
	</xsl:template>

</xsl:stylesheet>

